Changelog
=========

0.3.1 - unreleased
------------------

*   Fix broken source and wheel distributions. Now actually installable.

0.3.0 - 2016-03-10
------------------

*   Clean up broken symlinks from ``~/.fonts`` after uninstalling a font
    (removed from ``googlefonts.conf``).

*   Improve documentation.

0.2.0 - 2016-03-09
------------------

*   Packaging fix.

0.1.0 - 2016-03-09
------------------

*   Initial implementation.
